@@ -70,7 +70,10 @@ def get(environ, start_response):
             [('Content-Type', mime_type),
                 ('Vary', 'Accept')])
 
-    return content
+    if isinstance(content, basestring):
+        return [content]
+    else:
+        return content
 
 
 def get_tiddlers(environ, start_response):
